<template>
  <div class="edit-add-detail">
    <!-- <div class="crumbs">
      <Breadcrumb :breadcrumbOpt="breadcrumbOpt" svg-name="#icon-zuhuguanli" @breadcrumb-click="handleClose" />
    </div> -->
    <div class="form-content">
      <el-form ref="formInfo" :model="parameter" label-width="100px" :rules="rules" label-position="top">
        <div class="rows">
          <div class="rows-left">
            <div class="rows-hr"></div>
          </div>
          <div class="rows-title">
            <div class="text-overflow">基本信息</div>
          </div>
        </div>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="项目" prop="projectId">
              <el-select v-model="parameter.projectId" placeholder="请选择项目" style="width: 100%;" clearable>
                <el-option v-for="item in projectData" :key="item.id" :label="item.projectName" :value="item.id">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="楼栋名称" prop="buildingName">
              <el-input clearable v-model="parameter.buildingName" placeholder="请输入楼栋名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="楼栋编码" prop="buildingCode">
              <el-input clearable v-model="parameter.buildingCode" placeholder="请输入楼栋编码"></el-input>
            </el-form-item>
          </el-col>

        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="所属公司" prop="belongsOrgId">
              <el-cascader ref="cascaderOrg" v-model="orgValue" style="width: 100%;" :options="orgTree"
                :show-all-levels="false" @change="handelOrg" filterable
                :props="{ label: 'name', value: 'id', expandTrigger: 'hover', checkStrictly: true }"></el-cascader>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="楼栋号" prop="buildingNumber">
              <el-input clearable v-model="parameter.buildingNumber" placeholder="请输入楼栋号"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="楼层数" prop="floor">
              <el-input clearable v-model="parameter.floor" oninput="value=value.replace(/[^\d]/g,'')" placeholder="请输入楼层数"></el-input>
            </el-form-item>
          </el-col>

        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="地面层数" prop="floorGround">
              <el-input clearable v-model="parameter.floorGround" oninput="value=value.replace(/[^\d]/g,'')" placeholder="请输入地面层数"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="地下层数" prop="floorUnderground">
              <el-input clearable v-model="parameter.floorUnderground" oninput="value=value.replace(/[^\d]/g,'')" placeholder="地下层数"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="经度" prop="longitude">
              <el-input clearable v-model="parameter.longitude" oninput="value=value.replace(/^\D*(\d*(?:\.\d*)?).*$/g,'$1')" placeholder="请输入经度"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="纬度" prop="latitude">
              <el-input clearable v-model="parameter.latitude" oninput="value=value.replace(/^\D*(\d*(?:\.\d*)?).*$/g,'$1')" placeholder="请输入纬度"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="备注" prop="remark">
              <el-input type="textarea" :rows="2" clearable v-model="parameter.remark" placeholder="请输入备注"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div slot="footer" class="footer">
      <el-button type="primary" @click="handleSave">{{
        $t('domestic.save')
      }}</el-button>
      <el-button @click="handleClose">{{ $t('domestic.cancel') }}</el-button>
    </div>
  </div>
</template>

<script>
import utils from '@/utils.js'
import Breadcrumb from '@/components/Breadcrumb/index.vue'
import api from '@/api/assetsOperating/AssetLedgerRegistration/OperatingValuePublic.js'
import pubSub from 'pubsub-js'

export default {
  name: 'domesticDialog',
  components: { Breadcrumb },
  data() {
    return {
      breadcrumbOpt: [{ breadcrumbName: '楼栋信息' }, { breadcrumbName: '添加' }],
      rules: {
        projectId: [
          {
            required: true,
            message: '请选择项目',
            trigger: 'blur'
          }
        ],
        buildingName: [
          {
            required: true,
            message: '请输入楼栋名称',
            trigger: 'blur'
          }
        ],
        buildingCode: [
          {
            required: true,
            message: '请输入楼栋编码',
            trigger: 'blur'
          },
        ],
        belongsOrgId: [
          {
            required: true,
            message: '请选择所属公司',
            trigger: 'blur'
          }
        ],
        buildingNumber: [
          {
            required: true,
            message: '请输入楼栋号',
            trigger: 'blur'
          },

        ],
        floor: [
          {
            required: true,
            message: '请选择楼层数',
            trigger: 'blur'
          }
        ],
        floorGround: [
          {
            required: true,
            message: '请选择地面层数',
            trigger: 'blur'
          }
        ],
        floorUnderground: [
          {
            required: true,
            message: '请选择地下层数',
            trigger: 'blur'
          }
        ],
      },
      orgTree: [],//组织树
      orgValue: [],
      fullTree: [],//行政区划树
      fullValue: [],
      projectData: [],//项目信息
      parameter: {
      },
      orgId: '',//组织id
    }
  },
  created() {
    let curUserDetail = this.$store.state.user.currentUserDetail
    this.orgId = curUserDetail.org[0].orgId
    this.getUserOrgTree()
    this.getProject()
  },
  mounted() { },
  methods: {
    //编辑
    addModifyBtn(val) {
      this.parameter = {
        projectBelong: 0,
        projectNature: 0,
        projectSrc: 0,
        projectType: 0,
      }
      this.orgValue = utils.getAllParentArr(this.orgTree, this.orgId, 'id', 'children')
      this.$set(this.parameter)
      if (val) {
        this.breadcrumbOpt[1].breadcrumbName = '编辑'
        this.modifychoData(val)
      } else {
        this.orgValue = utils.getAllParentArr(this.orgTree, this.orgId, 'id', 'children')
        this.breadcrumbOpt[1].breadcrumbName = '添加'
        this.$nextTick(()=>{
          this.handelOrg()
        })
      }
    },
    //获取修改回显数据
    modifychoData(val) {
      api.detailsData(val.id, res => {
        if (res) {
          this.parameter = res
          if (res.belongsOrgFullId) {
            let orgId = utils.trimSpace(res.belongsOrgFullId.split('.')).pop()
            console.log(orgId);
            this.orgValue = utils.getAllParentArr(this.orgTree, orgId, 'id', 'children')
            console.log(this.orgValue);
          }
        }
      })
    },
    //获取组织树
    getUserOrgTree() {
      api.getUserOrgTree(this.orgId, res => {
        if (res) {
          this.orgTree = res
          // this.orgValue = utils.getAllParentArr(this.orgTree, this.orgId, 'id', 'children')
          // this.$set(this.orgValue)
        }
      })
    },
    //获取项目下拉
    getProject() {
      api.projectQquery({
        pageBean: {
          pageSize: -1,
          page: 1
        }
      }, res => {
        if (res.rows) {
          this.projectData = res.rows
        }
      })
    },

    //绑定所属公司
    handelOrg() {
      let data = this.$refs["cascaderOrg"].getCheckedNodes()[0].data
      this.parameter.belongsOrgFullId = data.path
      this.parameter.belongsOrgId = data.id
      this.parameter.belongsOrgName = data.name
    },

    // 关闭//面包屑点击
    handleClose() {
      pubSub.publish('go-back')

      this.$emit('closeComponent')
      this.parameter = {}
      this.$refs.formInfo.clearValidate()
    },
    // 保存
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          if (this.breadcrumbOpt[1].breadcrumbName === '添加') {
            api.addData(this.parameter, res => {
              if (res.state) {
                this.$message.success('保存成功')
                this.handleClose()
              }
            })
          } else if (this.breadcrumbOpt[1].breadcrumbName === '编辑') {
            api.editData(this.parameter, res => {
              if (res.state) {
                this.$message.success('编辑成功')
                this.handleClose()
              }
            })
          }
        }
      })
    }
  }
}
</script>

<style lang="scss" scoped>
.edit-add-detail {
  display: flex;
  flex-direction: column;

  // .crumbs {
  // }
  .form-content {
    flex: 1;
    // height: 80%;
    background-color: white;
    padding: 10px 20px;
    // margin-top: 20px;
    border-radius: 10px;
    overflow-y: scroll;
  }

  .form-content::-webkit-scrollbar {
    display: none;
    /* Chrome Safari */
  }

  .footer {
    height: 100px;
    background-color: white;
    margin-top: 20px;
    display: flex;
    justify-content: center;
    align-items: center;
  }
}

.rows {
  display: flex;
  align-items: center;
  border-bottom: 1px solid #ebebeb;
  margin-bottom: 16px;
  padding: 10px 0;

  .rows-left {
    margin-right: 10px;

    .rows-hr {
      width: 3px;
      height: 18px;
      background-color: #0e6eff;
      border-radius: 2px;
    }
  }

  .rows-title {
    .text-overflow {
      width: 100%;
      font-size: 16px;
    }
  }
}
</style>
